@@ -250,8 +250,10 @@ class PrintSettingsToolbox(QToolBox):
 
             if not all_pages and page_range:
                 cmd = ' '.join([cmd, '-o page-ranges=%s' % page_range])
-            fit_to_page = "fit-to-page"
-            cmd = ' '.join([cmd, '-o %s' % fit_to_page])
+
+            #fit_to_page = "fit-to-page"
+            # code added for ps orientation issue but its on cups 
+            #cmd = ' '.join([cmd, '-o %s' % fit_to_page])
 
             if page_set:
                 cmd = ' '.join([cmd, '-o page-set=%s' % page_set])
